#
# spec file for package mangohud
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define internal_ver %{version}
%define imgui_ver 1.89.9
%define imgui_wrap 1
%define implot_ver 0.16
%define vulkan_ver 1.2.158
Name:           mangohud
Version:        0.7.1
Release:        1.1
Summary:        A Vulkan and OpenGL overlay for monitoring
License:        MIT
URL:            https://github.com/flightlessmango/MangoHud
Source0:        %{url}/archive/v%{internal_ver}.tar.gz#/%{name}-%{internal_ver}.tar.gz
Source1:        https://github.com/ocornut/imgui/archive/v%{imgui_ver}/imgui-%{imgui_ver}.tar.gz
Source2:        https://wrapdb.mesonbuild.com/v2/imgui_%{imgui_ver}-%{imgui_wrap}/get_patch#/imgui-%{imgui_ver}-%{imgui_wrap}-wrap.zip
Source3:        https://wrapdb.mesonbuild.com/v2/vulkan-headers_%{vulkan_ver}-2/get_patch#/vulkan-headers-%{vulkan_ver}-2-wrap.zip
Source4:        https://github.com/KhronosGroup/Vulkan-Headers/archive/v%{vulkan_ver}.tar.gz#/vulkan-headers-%{vulkan_ver}.tar.gz
Source5:        https://github.com/epezent/implot/archive/refs/tags/v%{implot_ver}.zip#/implot-%{implot_ver}.tar.gz
Source6:        https://wrapdb.mesonbuild.com/v2/implot_%{implot_ver}-1/get_patch#/implot-%{implot_ver}-1-wrap.zip
Source99:       baselibs.conf
BuildRequires:  AppStream
%if 0%{?suse_version} < 1550 && 0%{?sle_version} >= 150500
BuildRequires:  gcc12-c++
%endif
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  glslang-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-mako
BuildRequires:  unzip
BuildRequires:  pkgconfig(cmocka)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libglvnd)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(x11)
Suggests:       goverlay
Provides:       bundled(ImGui)
Provides:       bundled(Vulkan-Headers-sdk)

%description
A Vulkan and OpenGL overlay for monitoring FPS, temperatures, CPU/GPU load and more.

%package -n mangoapp
Summary:        A transparent background application with a built-in MangoHud for gamescope
Group:          Games
Requires:       %{name}

%description -n mangoapp
A transparent background OpenGL application with a built-in MangoHud designed to be run inside a gamescope instance.

%package -n mangoplot
Summary:        Local visualization
Group:          Games
Requires:       %{name}
BuildArch:      noarch

%description -n mangoplot
mangoplot is a plotting script that is shipped with MangoHud: on a given folder,
it takes each log file, makes a 1D heatmap of its framerates,
then stacks the heats maps vertically to form a 2D graph for
easy visual comparison between benchmarks.

%prep
%autosetup -n MangoHud-%{internal_ver} -p1
%setup -n MangoHud-%{internal_ver} -DTa1
%setup -n MangoHud-%{internal_ver} -DTa2
%setup -n MangoHud-%{internal_ver} -DTa3
%setup -n MangoHud-%{internal_ver} -DTa4
%setup -n MangoHud-%{internal_ver} -DTa5
%setup -n MangoHud-%{internal_ver} -DTa6
sed -i -e '1d;2i#!%{_bindir}/bash' bin/mangohud.in
sed -i 's,^@ld_libdir_mangohud@ ,%{_prefix}/\$LIB/mangohud/,' bin/mangohud.in
sed -i 's|@ld_libdir_mangohud_abs@|%{_prefix}/\$LIB/mangohud|g' src/mangohud.json.in
mv imgui-%{imgui_ver} subprojects/
mv implot-%{implot_ver} subprojects/
mv Vulkan-Headers-%{vulkan_ver} subprojects/
sed -i 's/0.60.0/0.59/g' meson.build

# Fix tests building with GCC 13
sed -i -e '1i#include <cstdint>' tests/test_amdgpu.cpp

# Force system cmocka instead of bundled cmocka
sed -i "s/  cmocka = subproject('cmocka')//g" meson.build
sed -i "s/cmocka_dep = cmocka.get_variable('cmocka_dep')/cmocka_dep = dependency('cmocka')/g" meson.build

%build
%if 0%{?suse_version} < 1550 && 0%{?sle_version} >= 150500
export CC=gcc-12
export CXX=g++-12
%endif
%meson \
    -Dinclude_doc=true \
    -Duse_system_spdlog=enabled \
    -Dwith_wayland=enabled \
    -Dwith_xnvctrl=disabled \
    -Dtests=enabled \
    -Dmangoapp=true \
    -Dmangohudctl=true \
    -Dmangoapp_layer=true
    %{nil}
%meson_build

%install
%meson_install
sed -i "s@#!/usr/bin/env python@#!/usr/bin/python3@" %{buildroot}%{_bindir}/mangoplot

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/%{name}ctl
%{_libdir}/%{name}/
%{_datadir}/doc/%{name}/
%{_datadir}/vulkan/implicit_layer.d/
%{_mandir}/man1/mangohud.1%{?ext_man}
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/*/*/*/*.svg
%{_datadir}/metainfo/*.metainfo.xml

%files -n mangoapp
%{_bindir}/mangoapp
%{_mandir}/man1/mangoapp.1%{?ext_man}

%files -n mangoplot
%{_bindir}/mangoplot

%changelog
* Thu Feb  8 2024 Joshua Smith <jsmithfpv@gmail.com>
- Added implot to versioned directory to allow build
- Update to version 0.7.1:
  * Parameters:
  - gamepad_battery has been reworked to device_battery. This
    parameter current supports the values gamepad and mouse time
    now has a title
  - fps_metrics takes a decimal value or "avg". e.g avg,0.001 and
    displays the metrics
  - winesync shows the current implementation of synchronization
    primitives. E.g ESYNC/FSYNC etc
  - present_mode shows the current vulkan present mode or vsync
    status in opengl
  * Changes:
  - added support for gpu load on Adreno GPUs
  - added cpu temp for zenpower3 module
  - meson option: mangoplot
  * Fixes:
  - xnvctrl: fix an issue that could cause crashing when
    accessing gpu fan speed
  - fixed an issue where no config present wouldn't use default
    mangohud presets
  - fixed a crashing issue with CS2
  - reworked intel code. Should resolve some issues where
    mangohud didn't shutting down properly when using intel gpu
  - fix opengl runtime on musl libc systems
  - fixed text_outline_color incorrectly using BGR instead of RGB
* Fri Oct 20 2023 Dead Mozay <dead_mozay@opensuse.org>
- Restored mangoapp package.
- A separate mangoplot package has been created.
* Thu Oct 19 2023 Dead Mozay <dead_mozay@opensuse.org>
- Fix E: env-script-interpreter for mangoplot.
* Thu Oct 19 2023 Dead Mozay <dead_mozay@opensuse.org>
- Work restored for 32 bit applications (bsc#1215881)
* Fri Sep 29 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.0:
  * Parameters:
  - gpu_fan displays the gpu fan RPM, only works on AMD.
  - gpu_junction_temp displays the junction temperature on AMD GPUs.
  - removed io_stats, just use io_read and io_write instead.
  - engine_short_names shortens the names of engines, e.g VULKAN
    becomes VK.
  - text_outline adds a colored outline around all text.
  - text_outline_color sets the color of the outline,
    default: 000000.
  - text_outline_thickness sets the thickness of the outline,
    default: 1.5.
  - temp_fahrenheit changes all temps to fahrenheit from celsius.
  - dynamic_frame_timing dynamically changes the range of the
    frametime graph.
  - duration displays the time since mangohud initialized.
  - gpu_voltage shows the current gpu voltage, only works on AMD.
  - fps_text override fps text.
  - horizontal_stretch sets the background to stretch across
    width of application (enabled by default).
  - core_bars turns core_load into a histogram.
  - device_battery Shows battery level of wireless devices,
    accepts gamepad mouse.
  - device_battery_icon shows battery icon instead of percent.
  * preset: This parameter allows you to choose from a number
    of config presets.
  - 0: no display
  - 1: only fps.
  - 2: horizontal.
  - 3: more detailed default layout
  - 4: full
  * Changes:
  - Removed MANGOHUD_DLSYM because it's redundant.
  - Fixed core mhz when Cool'n'Quiet and similar is disabled
    in bios.
  - Added /etc/MangoHud.conf as a possible config location.
  - Add CPU architecture to vulkan manifest name.
  - mangoplot is a python script that graphs one or more mangohud
    csv logs.
  - mangoapp: resolved issue where different sized displays
    caused rendering issues.
  - mangohud script: guard so we don't add mangohud
    lib to LD_PRELOAD multiple times.
  - split mangohud into two shared libraries, one for vulkan and
    one for opengl. This should resolve issues where mangohud
    would init vulkan and opengl at the same time.
  - statically link stdc++. This fixed a lot of crashing issues
    when MANGOHUD=1 was set before starting steam.
  - added support for zenergy kernel driver.
  - fixed alpha param that stopped working at some point.
  - added --version to mangohud script.
  - When using horizontal layout set table_columns param to
    current count of table_columns instead of manually.
  - Intel GPU: use fdinfo for GPU load.
  - logging: calculate fps data using frametime.
  - AMDGPU: get core clock from hwmon instead of gpu_metrics.
  - gamepad_battery is now deprecated
    use device_battery= mouse or gamepad.
  - logging: added process RSS and swap usage.
  - Fixed a memory leak when resizing vulkan windows.
  * Blacklist:
  - blacklist: if blacklisted application is hardcoded,
    don't proceed to load config blacklists.
  - blacklist: only print blacklist info message once.
    + blacklist: added more hardcoded entries:
  - tabtip.exe
  - steam.exe
  - wine64-preloader
  - explorer.exe
  - wine-preloader
  - iexplore.exe
  - rundll32.exe
* Mon Apr 17 2023 Simon Vogl <simon.vogl@gmx.net>
- Drop 0001-fix-gcc13-build.patch and instead do the same with sed
  inside the spec file
- Update to version 0.6.9~1:
  * Fixed issue that applied picmip without option being set
  * Reverted x11 poller that was causing segfaults 06edee4
  * Fixed issues with horizontal and legacy_layout
  * Fixed amdgpu APU power and temperature reading
  * Fixed certain hud elements displaying incorrectly in horizontal
  * Fixed an issue causing segfault when using MANGOHUD_CONFIG
* Fri Apr 14 2023 Simon Vogl <simon.vogl@gmx.net>
- Add 0001-fix-gcc13-build.patch to fix build with openSUSE's gcc13
- Now package mangohudctl, now package mangoapp as a sub-package
- Drop support for openSUSE Leap 15.4 as it cannot
  provide any compiler that works with mangohud >= 0.6.9
- Update to version 0.6.9:
  * Add missing division for fallback AMD CPU power calculation.
  * workflow: arch release package
  * gpu: amdgpuinfo: ifdef linux for windows build
  * bump minhook wrap rev
  * workflow: mingw: fetch git
  * use minhook subproject instead of module
  * workflow: mingw build test
* Tue Apr  4 2023 Dead Mozay <dead_mozay@opensuse.org>
- Disabled compilation with system libraries vulkan-headers
  * https://github.com/flightlessmango/MangoHud/pull/975
- Added BuildRequires glew, glfw3, nlohmann_json.
* Tue Mar 28 2023 Dead Mozay <dead_mozay@opensuse.org>
- Fix building with GCC 13
* Sat Nov 26 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build by extracting the imgui to the versioned directory,
  where it belongs, as specified in the .wrap file (fixes build
  with meson 0.64, which got stricter on this front).
* Tue Aug  2 2022 Dead Mozay <dead_mozay@opensuse.org>
- Cleaning spec.
* Mon Aug  1 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.8:
  * Fixes MangoHud not loading with latest DXVK.
  * Use of system spdlog dependency.
  * Fixed table_columns not working as expected.
  * Minor adjustments to hud elements and imgui.
  * Added MANGOHUD_LOG_LEVEL env variable
    it takes off, info, err, warn.
  * Added FCAT support.
  * Disabled gamepad_battery_icon by default.
  * Generalize control over socket so it works with OpenGL as well.
  * AMDGPU: fixed gfx and cpu power metrics being parsed incorrectly.
  * fps_only disables legacy_layout by default.
* Sat May 14 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.7~1:
  * amdgpu: Prefer sysfs temp over gpu_metrics.
  * amdgpu: Fix incorrect gpu load for some GPUs.
  * amdgpu: If gpu_metrics is from v1_0, ignore it and
    use sysfs instead.
  * Fixed on screen benchmark not matching summary file.
  * Fixed zink detection.
  * disabled throttling_status by default for nvidia as it causes
    lag on 3000 series.
* Wed May  4 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.6.7:
  * Show highest cpu freq instead of the cumulative average
  * Using sysfs scaling_cur_freq instead of /proc/cpuinfo for cpu core frequencies
  * Added EADesktop.exe and EALauncher.exe to blacklist
  * Logger writes a summary by default
  * Using gpu_metrics sysfs binary for amdgpu metrics
  * Showing min and max frametime for the period
  * Battery param shows a plug icon when plugged in
  * Improved amdgpu metrics accuracy by polling 100times per period
  * Fixed splitgate crashing on amd gpu's
  * Fixed not reporting amd cpu power when using the zenpower module
  * Fixed regression in hardware info updater
  * Fixed bug where setting cpu cores to offline would crash mangohud/mangoapp
* Sun Mar 13 2022 Simon Vogl <simon.vogl@gmx.net>
- Update to version 0.6.6 & 0.6.6.1:
  * fix mangoapp building without xnvctrl
  * Fixed logging crashing in some games (cyberpunk etc)
  * Limit keybind check to about 10hz (improves perf in high fps scenarios, like vkcube)
  * Added spdlog
  * Changed media_player_order to media_player_format={title};{artist};{album}. Semi-colon adds a new line.
- Switched to a new %%{internal_ver} macro for building as the internal version number 0.6.6-1 does not synergize with openSUSE's versioning system.
- Add spdlog as it is now required to build mangohud, don't use system spdlog as mangohud needs version 1.8.5 specifically.
* Fri Jul  9 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.5:
  * Fixed more issues where incorrect engine name would be shown.
  * ToGL detection.
  * middle-left and middle-right are now options in the position param.
  * Fixed issue where vulkan driver version would be incorrect.
* Thu Jun 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.4:
  * Fixed issue where some games would crash on startup.
  * Fixed issue where Battery param would cause a stutter.
  * Fixed issue where engine would incorrectly show "vulkan".
* Sat Jun 12 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.3:
  * core_load_change    Changes the colors of cpu core loads, uses the
    same data from cpu_load_value and cpu_load_change resolution
    Display the current resolution
  * show_fps_limit 	Display the current fps limit
  * custom_text_center 	Display a custom centered text, only works with legacy_layout=false
  * custom_text 	Display a custom text, only works with legacy_layout=false
  * exec 		Display output of bash command in next column, e.g
    custom_text=/home
    exec=df -h /home | tail -n 1. only works with legacy_layout=false
  * gamemode 		Displays whether gamemode is enabled or not
  * vkbasalt 		Displays whether vkbasalt is enabled or not
  * swap 		Displays swap space usage next to system RAM usage
  * battery 		Display current battery percent and energy consumption
  * battery_icon 	Display battery icon instead of percent
  * battery_color 	Change the BATT text color
  * round_corners 	Change the amount of roundness of the corners have e.g round_corners=10.0
* Wed Feb 10 2021 Dead Mozay <dead_mozay@opensuse.org>
- Add baselibs.conf for 32bit package.
* Mon Feb  1 2021 Dead Mozay <dead-mozay@opensuse.org>
- Fix LD_LIBRARY_PATH for 32bit apps (boo#1180826)
* Mon Nov 30 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.1:
  * Fix cpu power related crash
* Sun Nov 29 2020 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.6.0:
  * Fixed MangoHud OpenGL not showing in Black Ice
  * Fixed MangoHud OpenGL being a black box in Total War: MEDIEVAL II
  * Fixed MangoHud OpenGL not working in Divinity Original Sin
    Enhanced Edition
  * Fixed MangoHud OpenGL not working in Mount & Blade: Warband
  * Attempted fix for fps limit sometimes breaking
  * Fixed colors not updating
  * Moved frame_timing ms to above the graph instead of beside
  * Allow graphs to take up the entire region
  * Permitting more delimiters, , : and + are now acceptable
* Sun Oct 18 2020 Dead Mozay <dead-mozay@opensuse.org>
- Fix shebang
* Mon Aug 17 2020 dead_mozay@opensuse.org
- Update to version 0.5.1:
  * Fixed a memory leak in Source Engine 1 games (CSGO, TF2 etc)
  * You can use mangohud --dlsym as an alternative to
    MANGOHUD_DLSYM=1
  * MangoHud now comes with a man page man mangohud
  * output_file is now replaced by output_folder,
    the files are automatically named after the programs executable
  * By pressing Shift_L+F3 you will automatically upload the latest
    log file to Flightlessmango.com and open up said benchmark.
    To upload all logs for this session, the default keybind is
    Control_L=F3. Both of these require that you set the
    permit_upload param to 1 and output_folder
  * Added supported for more glyph ranges
* Fri Jun 12 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
